# AE1 model based on Weinstein 2000

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    fkc = 1e6
    Kc = 50 # [=] mM
    Kb = 198 # [=] mM
    Pc = [562, 61]
    Pb = [1247, 135]

    # rxn order
    # 1 X' + Cl > Cl.X'
    # 2 Cl.X' > Cl.X''
    # 3 Cl.X'' > X'' + Cl
    # 4 B + X'' > B.X''
    # 5 B.X'' > B.X'
    # 6 B.X' > B + X'

    # detailed bal is already satisfied in kinetic model

    kf =[fkc, Pc[0], fkc*Kc, fkc, Pb[1], fkc*Kb]
    kr =[fkc*Kc, Pc[1], fkc, fkc*Kb, Pb[0], fkc]

    # kr[5] = np.product(kf)/(np.product(kr[0:4]))
    k_kinetic = kf + kr

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo'], V['V_o']]*int(num_rows/2)

    return (k_kinetic, N_cT, K_C, W)













